@@ -75,7 +75,12 @@ ScreenShotSource2::ScreenShotSource2(const QString &methodName, ArgType... argum
 
         if (reply.isError()) {
             qWarning() << "Screenshot request failed:" << reply.error().message();
-            Q_EMIT errorOccurred();
+            if (reply.error().name() == QStringLiteral("org.kde.KWin.ScreenShot2.Error.Cancelled")) {
+                // don't show error on user cancellation
+                Q_EMIT finished(m_result);
+            } else {
+                Q_EMIT errorOccurred();
+            }
         } else {
             handleMetaDataReceived(reply);
         }
@@ -283,7 +288,7 @@ void PlatformKWinWayland2::doGrab(ShutterMode, GrabMode theGrabMode,
 
     switch (theGrabMode) {
     case GrabMode::AllScreens:
-        takeScreenShotArea(workArea(), flags & ~ScreenShotFlags(ScreenShotFlag::NativeSize));
+        takeScreenShotArea(workArea(), flags);
         break;
     case GrabMode::CurrentScreen:
         takeScreenShotInteractive(InteractiveKind::Screen, flags);
@@ -292,7 +297,7 @@ void PlatformKWinWayland2::doGrab(ShutterMode, GrabMode theGrabMode,
         takeScreenShotInteractive(InteractiveKind::Window, flags);
         break;
     case GrabMode::AllScreensScaled:
-        takeScreenShotArea(workArea(), flags);
+        takeScreenShotArea(workArea(), flags & ~ScreenShotFlags(ScreenShotFlag::NativeSize));
         break;
     case GrabMode::PerScreenImageNative:
         takeScreenShotScreens(QGuiApplication::screens(), flags);
